==> sms-ping-1.8.0-sources.jar: org/opennms/sms/ping/internal/SmsPingTrackerImpl.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.ping.internal;

import java.io.IOException;

import org.apache.log4j.Logger;
import org.opennms.protocols.rt.IDBasedRequestLocator;
import org.opennms.protocols.rt.RequestTracker;
import org.opennms.sms.ping.PingRequestId;
import org.opennms.sms.ping.PingResponseCallback;
import org.opennms.sms.ping.SmsPingTracker;

/**
 * SmsPingTrackerImpl
 *
 * @author brozow
 */
public class SmsPingTrackerImpl extends RequestTracker<PingRequest, PingReply> implements SmsPingTracker {
    
    private static Logger log = Logger.getLogger(SmsPingTrackerImpl.class);

    public SmsPingTrackerImpl(SmsPingMessenger smsMessenger) throws IOException {
        super("SMS", smsMessenger, new IDBasedRequestLocator<PingRequestId, PingRequest, PingReply>());
        log.debug("Created SmsPingTrackerImpl");
    }

    public void sendRequest(String phoneNumber, long timeout, int retries, PingResponseCallback cb) throws Exception {
        sendRequest(new PingRequest(new PingRequestId(phoneNumber), timeout, retries, cb));
    }

    /* (non-Javadoc)
     * @see org.opennms.protocols.rt.RequestTracker#start()
     */
    @Override
    public synchronized void start() {
        log.debug("Calling start()");
        super.start();
        log.debug("Called start()");
    }
    

    public void stop() {
        log.debug("Calling stop()");

        log.debug("Called stop()");
    }
    
    

}

==> sms-ping-1.8.11-sources.jar: org/opennms/sms/ping/internal/SmsPingTrackerImpl.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.ping.internal;

import java.io.IOException;

import org.apache.log4j.Logger;
import org.opennms.protocols.rt.IDBasedRequestLocator;
import org.opennms.protocols.rt.RequestTracker;
import org.opennms.sms.ping.PingRequestId;
import org.opennms.sms.ping.PingResponseCallback;
import org.opennms.sms.ping.SmsPingTracker;

/**
 * SmsPingTrackerImpl
 *
 * @author brozow
 * @version $Id: $
 */
public class SmsPingTrackerImpl extends RequestTracker<PingRequest, PingReply> implements SmsPingTracker {
    
    private static Logger log = Logger.getLogger(SmsPingTrackerImpl.class);

    /**
     * <p>Constructor for SmsPingTrackerImpl.</p>
     *
     * @param smsMessenger a {@link org.opennms.sms.ping.internal.SmsPingMessenger} object.
     * @throws java.io.IOException if any.
     */
    public SmsPingTrackerImpl(SmsPingMessenger smsMessenger) throws IOException {
        super("SMS", smsMessenger, new IDBasedRequestLocator<PingRequestId, PingRequest, PingReply>());
        log.debug("Created SmsPingTrackerImpl");
    }

    /** {@inheritDoc} */
    public void sendRequest(String phoneNumber, long timeout, int retries, PingResponseCallback cb) throws Exception {
        sendRequest(new PingRequest(new PingRequestId(phoneNumber), timeout, retries, cb));
    }

    /* (non-Javadoc)
     * @see org.opennms.protocols.rt.RequestTracker#start()
     */
    /** {@inheritDoc} */
    @Override
    public synchronized void start() {
        log.debug("Calling start()");
        super.start();
        log.debug("Called start()");
    }
    

    /**
     * <p>stop</p>
     */
    public void stop() {
        log.debug("Calling stop()");

        log.debug("Called stop()");
    }
    
    

}
